summaryrefslogtreecommitdiff
path: root/windows/win_regedit.py
diff options
context:
space:
mode:
authorAdam Keech <akeech@chathamfinancial.com>2015-07-01 09:53:35 -0400
committerAdam Keech <akeech@chathamfinancial.com>2015-07-06 15:25:28 -0400
commite84666fd7428012e29e013e792aa5574e6892c75 (patch)
tree20d8b243863d5c9fa441fdb7f89759a40784d192 /windows/win_regedit.py
parent5a2a22bf68b6cd305e6dbfe1a0044eaf5d9398ed (diff)
downloadansible-modules-extras-e84666fd7428012e29e013e792aa5574e6892c75.tar.gz
Renaming variables in win_regedit module to make more sense with actions that are happening.
Diffstat (limited to 'windows/win_regedit.py')
-rw-r--r--windows/win_regedit.py43
1 files changed, 21 insertions, 22 deletions
diff --git a/windows/win_regedit.py b/windows/win_regedit.py
index 007ddd4e..d8fd3a7c 100644
--- a/windows/win_regedit.py
+++ b/windows/win_regedit.py
@@ -25,25 +25,25 @@ DOCUMENTATION = '''
---
module: win_regedit
version_added: "2.0"
-short_description: Add, Edit, or Remove Registry Key
+short_description: Add, Edit, or Remove Registry Value
description:
- - Add, Edit, or Remove Registry Key using ItemProperties Cmdlets
+ - Add, Edit, or Remove Registry Value using ItemProperties Cmdlets
options:
name:
description:
- - Name of Registry Key
+ - Name of Registry Value
required: true
default: null
aliases: []
- value:
+ data:
description:
- - Value of Registry Key
+ - Registry Value Data
required: false
default: null
aliases: []
- valuetype:
+ type:
description:
- - Type of Registry Key
+ - Registry Value Data Type
required: false
choices:
- binary
@@ -56,13 +56,13 @@ options:
aliases: []
path:
description:
- - Path of Registry Key
+ - Path of Registry Value
required: true
default: null
aliases: []
state:
description:
- - State of Registry Key
+ - State of Registry Value
required: false
choices:
- present
@@ -73,29 +73,28 @@ author: "Adam Keech (@smadam813), Josh Ludwig (@joshludwig)"
'''
EXAMPLES = '''
- # Add Registry Key (Default is String)
+ # Add Registry Value (Default is String)
win_regedit:
- name: testkey
- value: 1337
+ name: testvalue
+ data: 1337
path: HKCU:\Software\MyCompany
- # Add Registry Key with Type DWord
+ # Add Registry Value with Type DWord
win_regedit:
- name: testkey
- value: 1337
- valuetype: dword
+ name: testvalue
+ data: 1337
+ type: dword
path: HKCU:\Software\MyCompany
# Edit Registry Key called testkey
win_regedit:
- name: testkey
- value: 8008
+ name: testvalue
+ data: 8008
path: HKCU:\Software\MyCompany
# Remove Registry Key called testkey
win_regedit:
- name: testkey
+ name: testvalue
path: HKCU:\Software\MyCompany
state: absent
'''
-
@@ -73,29 +73,28 @@ author: "Adam Keech (@smadam813), Josh Ludwig (@joshludwig)"
path: HKCU:\Software\MyCompany
- # Edit Registry Key called testkey
+ # Edit Registry Value called testvalue
win_regedit:
@@ -73,29 +73,28 @@ author: "Adam Keech (@smadam813), Josh Ludwig (@joshludwig)"
path: HKCU:\Software\MyCompany
- # Remove Registry Key called testkey
+ # Remove Registry Value called testvalue
win_regedit: